@@ -8,8 +8,7 @@ refer to documentation of individual modules for API details.
 """
 
 from jeepney.bus_messages import message_bus
-from jeepney.integrate.blocking import DBusConnection, Proxy, \
- connect_and_authenticate
+from jeepney.io.blocking import DBusConnection, Proxy, open_dbus_connection
 
 from secretstorage.collection import Collection, create_collection, \
  get_all_collections, get_default_collection, get_any_collection, \
@@ -20,7 +19,7 @@ from secretstorage.exceptions import SecretStorageException, \
  ItemNotFoundException, PromptDismissedException
 from secretstorage.util import add_match_rules
 
-__version_tuple__ = (3, 2, 0)
+__version_tuple__ = (3, 3, 0)
 __version__ = '.'.join(map(str, __version_tuple__))
 
 __all__ = [
@@ -70,7 +69,7 @@ def dbus_init() -> DBusConnection:
 	   This function no longer accepts any arguments.
 	"""
 	try:
-		connection = connect_and_authenticate()
+		connection = open_dbus_connection()
 		add_match_rules(connection)
 		return connection
 	except KeyError as ex:
@@ -82,7 +81,7 @@ def dbus_init() -> DBusConnection:
 
 
 def check_service_availability(connection: DBusConnection) -> bool:
-	"""Returns True if the Security Service daemon is either running or
+	"""Returns True if the Secret Service daemon is either running or
 	available for activation via D-Bus, False otherwise.
 
 	.. versionadded:: 3.2
